"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useNavigation;
var React = _interopRequireWildcard(require("react"));
var _navigationUtils = require("./navigationUtils");
var _useCurrentRoot = _interopRequireDefault(require("./useCurrentRoot"));
var _OptimizedContext = _interopRequireDefault(require("./contexts/OptimizedContext"));
var _useBottomTabIndex = _interopRequireDefault(require("./useBottomTabIndex"));
var _reactNative = require("react-native");
var _RidgeNavigationContext = _interopRequireDefault(require("./contexts/RidgeNavigationContext"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function useNavigation() {
  const {
    rootNavigator,
    preloadRoot,
    preloadScreen,
    preloadElement,
    theme,
    stateNavigator
  } = React.useContext(_OptimizedContext.default);
  const {
    fluent,
    navigationRoot
  } = React.useContext(_RidgeNavigationContext.default);
  const {
    currentRootKey,
    currentRoot
  } = (0, _useCurrentRoot.default)();
  const {
    currentTab,
    switchToTab
  } = (0, _useBottomTabIndex.default)();
  const preload = React.useCallback(async (screen, params) => {
    preloadScreen(screen, params);
  }, [preloadScreen]);
  const canNavigateBack = React.useCallback(dist => {
    return stateNavigator.canNavigateBack(dist || 1);
  }, [stateNavigator]);
  const popToTop = React.useCallback(() => {
    const {
      crumbs
    } = stateNavigator.stateContext;
    stateNavigator.navigateBack(crumbs.length);
  }, [stateNavigator]);
  const pop = React.useCallback(dist => {
    let distance = 1;
    if (typeof dist === 'number') {
      distance = dist;
    }
    if (stateNavigator.canNavigateBack(distance)) {
      stateNavigator.navigateBack(distance);
    } else {
      console.log('can not navigate back');
    }
  }, [stateNavigator]);
  const switchRoot = React.useCallback(function (rootKey) {
    let preloadSetting = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
    if (preloadSetting) {
      preloadRoot(rootKey);
    }
    const root = navigationRoot[rootKey];
    const screenKey = _reactNative.Platform.select({
      web: (0, _navigationUtils.getScreenKey)(rootKey, (root === null || root === void 0 ? void 0 : root.type) === 'bottomTabs' ? root.children[0] : undefined, (root === null || root === void 0 ? void 0 : root.type) === 'bottomTabs' ? root.children[0].path : root === null || root === void 0 ? void 0 : root.child.path),
      default: rootKey
    });
    rootNavigator.start(screenKey);
  }, [preloadRoot, navigationRoot, rootNavigator]);
  const refresh = React.useCallback((screen, params, options) => {
    if (options !== null && options !== void 0 && options.preload) {
      preload(screen, params);
    }
    stateNavigator.refresh(params, 'replace');
  }, [stateNavigator, preload]);
  const innerNavigate = React.useCallback((screen, params, options, historyAction) => {
    if (options !== null && options !== void 0 && options.preload) {
      preload(screen, params);
    }

    // on web, it works based on url but on mobile it works based on bottom tab index
    if (options !== null && options !== void 0 && options.toBottomTab && _reactNative.Platform.OS !== 'web') {
      switchToTab(options.toBottomTab);
    } else {
      const screenKey = (0, _navigationUtils.getScreenKey)(currentRootKey, (options === null || options === void 0 ? void 0 : options.toBottomTab) || currentTab, screen.path);
      stateNavigator.navigate(screenKey, params, historyAction);
    }
  }, [currentRootKey, currentTab, stateNavigator, preload, switchToTab]);
  const push = React.useCallback((screen, params, options) => {
    innerNavigate(screen, params, options);
  }, [innerNavigate]);
  const replace = React.useCallback((screen, params, options) => {
    if (options !== null && options !== void 0 && options.preload) {
      preload(screen, params);
    }
    const screenKey = (0, _navigationUtils.getScreenKey)(currentRootKey, (options === null || options === void 0 ? void 0 : options.toBottomTab) || currentTab, screen.path);
    const url = stateNavigator.fluent(true).navigateBack(1).navigate(screenKey, params).url;
    stateNavigator.navigateLink(url);
  }, [currentRootKey, currentTab, preload, stateNavigator]);
  return {
    currentRootKey,
    currentRoot,
    preloadElement,
    preloadRoot,
    preload,
    pop,
    popToTop,
    switchRoot,
    push,
    replace,
    refresh,
    theme,
    canNavigateBack,
    fluent
  };
}
//# sourceMappingURL=useNavigation.js.map